@@ -12,8 +12,8 @@ from aiconfig.default_parsers.openai import (
 )
 from aiconfig.default_parsers.palm import PaLMChatParser, PaLMTextParser
 from aiconfig.model_parser import InferenceOptions, ModelParser
-from .AIConfigSettings import AIConfig, ConfigMetadata, Prompt
-from .registry import ModelParserRegistry
+from .schema import AIConfig, ConfigMetadata, Prompt
+from .registry import ModelParserRegistry, update_model_parser_registry_with_config_runtime
 
 gpt_models = [
         "gpt-4",
@@ -39,6 +39,7 @@ class AIConfigRuntime(AIConfig):
     # TODO: Define a default constructor that will construct with default values. This seems a little complicated because of the way pydantic works. Pydantic creates its own constructors.
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
+        self.file_path = None
 
     @classmethod
     def create(
@@ -70,7 +71,7 @@ class AIConfigRuntime(AIConfig):
         )
 
     @classmethod
-    def from_config(cls, json_config_filepath) -> "AIConfigRuntime":
+    def load(cls, json_config_filepath) -> "AIConfigRuntime":
         """
         Constructs AIConfigRuntime from a JSON file given its file path and returns it.
 
@@ -81,7 +82,12 @@ class AIConfigRuntime(AIConfig):
         with open(json_config_filepath) as file:
             # load the file as bytes and let pydantic handle the parsing
             # validated_data =  AIConfig.model_validate_json(file.read())
-            return cls.model_validate_json(file.read())
+            aiconfigruntime = cls.model_validate_json(file.read())
+            update_model_parser_registry_with_config_runtime(aiconfigruntime)
+
+            # set the file path. This is used when saving the config
+            aiconfigruntime.file_path = json_config_filepath
+            return aiconfigruntime
 
     @classmethod
     def load_from_workbook(cls, workbook_id: str) -> "AIConfigRuntime":
@@ -111,13 +117,36 @@ class AIConfigRuntime(AIConfig):
                 raise Exception(f"Failed to load workbook. Status code: {resp.status_code}")
 
             data = resp.json()
-            return cls.model_validate_json(data)
+
+            aiconfigruntime = cls.model_validate_json(data)
+            update_model_parser_registry_with_config_runtime(aiconfigruntime)
+            return aiconfigruntime
+
+    async def serialize(self, model_name: str, data: Dict,  prompt_name: str, params: Optional[dict] = {}) -> List[Prompt]:
+        """
+        Serializes the completion params into a Prompt object. Inverse of the 'resolve' function.
+
+        args:
+            model_name (str): The model name to create a Prompt object for
+            data (dict): The data to save as a Prompt Object
+            params (dict, optional): Optional parameters to save alongside the prompt
+
+        returns:
+            Prompt | List[Prompt]: A prompt or list of prompts representing the input data
+        """
+        model_parser = ModelParserRegistry.get_model_parser(model_name)
+        if not model_parser:
+            raise ValueError(
+                f"Unable to serialize data: `{data}`\n Model Parser for model {model_name} does not exist."
+            )
+
+        prompts = model_parser.serialize(prompt_name, data, self, params)
+        return prompts
 
     async def resolve(
         self,
         prompt_name: str,
         params: Optional[dict] = {},
-        options: Optional[InferenceOptions] = None,
         **kwargs,
     ):
         """
@@ -138,17 +167,17 @@ class AIConfigRuntime(AIConfig):
             )
 
         prompt_data = self.prompt_index[prompt_name]
-        model_name = prompt_data.get_model_name()
+        model_name = self.get_model_name(prompt_data)
         model_provider = AIConfigRuntime.get_model_parser(model_name)
 
-        response = await model_provider.deserialize(prompt_data, self, options, params)
+        response = await model_provider.deserialize(prompt_data, self, params)
 
         return response
 
     async def run(
         self,
-        prompt_name: Optional[str],
-        params: Optional[dict],        
+        prompt_name: str,
+        params: Optional[dict] = {},        
         options: Optional[InferenceOptions] = None,
         **kwargs,
     ):
@@ -170,7 +199,7 @@ class AIConfigRuntime(AIConfig):
             )
 
         prompt_data = self.prompt_index[prompt_name]
-        model_name = prompt_data.get_model_name()
+        model_name = self.get_model_name(prompt_data)
         model_provider = AIConfigRuntime.get_model_parser(model_name)
 
         response = await model_provider.run(prompt_data, self, options, params, **kwargs)
@@ -182,7 +211,7 @@ class AIConfigRuntime(AIConfig):
     #    @param saveOptions Options that determine how to save the AIConfig to the file.
     #    */
 
-    def save(self, json_config_filepath: str = "aiconfig.json"):
+    def save(self, json_config_filepath: str = None, include_outputs: bool = True):
         """
         Save the AI Configuration to a JSON file.
 
@@ -190,14 +219,28 @@ class AIConfigRuntime(AIConfig):
             json_config_filepath (str, optional): The file path to the JSON configuration file.
                 Defaults to "aiconfig.json".
         """
+        exclude_options = {
+            "prompt_index": True, 
+            "file_path": True
+        }
+
+        if not include_outputs:
+            exclude_options["prompts"] = {"__all__": {"outputs"}}
+            pass
+
+        if not json_config_filepath:
+            json_config_filepath = self.file_path or "aiconfig.json"
+
         with open(json_config_filepath, "w") as file:
             # Serialize the AI Configuration to JSON and save it to the file
             json.dump(
                 self.model_dump(
                     mode="json",
-                    exclude={"prompt_index": True, "prompts": {"__all__": {"outputs"}}},
+                    exclude=exclude_options,
+                    exclude_none=True,
                 ),
                 file,
+                indent=2,
             )
 
     def get_output_text(self, prompt: str | Prompt, output: Optional[dict] = None) -> str:
@@ -213,18 +256,18 @@ class AIConfigRuntime(AIConfig):
         """
         if isinstance(prompt, str):
             prompt = self.get_prompt(prompt)
-        model_parser = ModelParserRegistry.get_model_parser_for_prompt(prompt)
+        model_parser = ModelParserRegistry.get_model_parser_for_prompt(prompt, self)
         return model_parser.get_output_text(prompt, self, output)
 
     @staticmethod
-    def register_model_parser(model_parser: ModelParser):
+    def register_model_parser(model_parser: ModelParser, model_name: str):
         """
         Registers a model parser to the registry.
 
         Args:
             model_parser (ModelParser): The model parser to be registered.
         """
-        ModelParserRegistry.register_model_parser(model_parser)
+        ModelParserRegistry.register_model_parser(model_parser, [model_name])
 
     @staticmethod
     def get_model_parser(model_id: str) -> ModelParser:
