@@ -17,7 +17,7 @@ async def test_load_basic_chatgpt_query_config(set_temporary_env_vars):
     """Test loading a basic chatgpt query config"""
     config_relative_path = "aiconfigs/basic_chatgpt_query_config.json"
     config_absolute_path = get_absolute_file_path_from_relative(__file__, config_relative_path)
-    config = AIConfigRuntime.from_config(config_absolute_path)
+    config = AIConfigRuntime.load(config_absolute_path)
 
     data_for_inference = await config.resolve("prompt1")
 
@@ -34,7 +34,7 @@ async def test_chained_gpt_config(set_temporary_env_vars):
     """Test loading a chained gpt config and resolving it, with chat context enabled"""
     config_relative_path = "aiconfigs/chained_gpt_config.json"
     config_absolute_path = get_absolute_file_path_from_relative(__file__, config_relative_path)
-    config = AIConfigRuntime.from_config(config_absolute_path)
+    config = AIConfigRuntime.load(config_absolute_path)
 
     data_for_inference1 = await config.resolve("prompt1")
 
@@ -79,7 +79,7 @@ async def test_resolve_system_prompt():
     """
     config_relative_path = "aiconfigs/system_prompt_parameters_config.json"
     config_absolute_path = get_absolute_file_path_from_relative(__file__, config_relative_path)
-    config = AIConfigRuntime.from_config(config_absolute_path)
+    config = AIConfigRuntime.load(config_absolute_path)
 
     data_for_inference = await config.resolve("prompt1", {"system": "skip odd numbers"})
     assert data_for_inference == {
