@@ -1,7 +1,7 @@
 from aiconfig.util.config_utils import extract_override_settings
 import pytest
 from aiconfig.Config import AIConfigRuntime
-from aiconfig.AIConfigSettings import (
+from aiconfig.schema import (
     AIConfig,
     ConfigMetadata,
     ExecuteResult,
@@ -334,7 +334,7 @@ def test_load_saved_config(tmp_path):
     json_config_filepath = tmp_path / "my_aiconfig.json"
     config_runtime.save(json_config_filepath)
 
-    loaded_config = AIConfigRuntime.from_config(json_config_filepath)
+    loaded_config = AIConfigRuntime.load(json_config_filepath)
 
     # Ensure the loaded AIConfig contains the expected data
     assert loaded_config.name == "My AIConfig"
